import { select, min, max, scaleLinear, mean} from 'd3';

import { dropDownMenu } from './dropDownMenu';


const width = document.body.clientWidth;
const height = document.body.clientHeight;

const svg = select('svg')
    .attr('width', width)
    .attr('height', height);

svg
  .append('rect')
    .attr('width', width)
    .attr('height', height)
    .attr('rx', 40)

const x = width / 2;
const y = height / 2;
const m = min([x, y]) - 70;

const value = d => Math.sqrt(d);
const opts = [
  'TR: Triangular', 
  'B1: Botstrap-1', 
  'BR: Bootstrap-Rate'
];

let xColumn = opts[0];

const onXColumnClicked = column => {
  xColumn = column;  
	render(aircrafts[xColumn]);
};

let durs;
const aircrafts = {};

select('div.choice')
  .call(dropDownMenu, {
    options: opts,
    onOptionClicked: onXColumnClicked,
    selectedOption: xColumn
});

let strokeWidth = '1px';
const render = data => {
  let avg = mean(data);
  const maxRadius = max(data, value);
  const scale = scaleLinear()
    .domain([0, maxRadius])
    .range([0, m]);
  
  let circles = svg.selectAll('circle').data(data);

  circles
    .enter().append('circle')
       .attr('cx', x)
       .attr('cy', y)
       .attr('r', scale(value(avg)))
       .attr('fill', 'none')
       .attr('stroke','rgba(250, 250, 250, 0.05)')
       .attr('stroke-width', strokeWidth)
    .merge(circles)
    .transition().duration(800)
       .attr('r', d => scale(value(d)));

  circles.exit()
    .transition().duration(150)
      .attr('r', 0)
    .remove();

  let circleAvg = svg.selectAll('circle.avg').data([avg]);
  circleAvg
    .enter().append('circle')
       .attr('class', 'avg')
       .attr('cx', x)
       .attr('cy', y)
       .attr('fill', 'none')
       .attr('stroke','rgba(255, 0, 0)')
       .attr('stroke-width', '3px')
    .merge(circleAvg)
    .transition().duration(1000)
       .attr('r', scale(value(avg)))
}


d3.csv('https://vizhub.com/rubens2005/datasets/P0210.csv')
  .then(data => {
    durs = data;
    durs.forEach(d => {
      d.dur = +d.dur;
      d.distr = d.distr.substring(1,3)
    })
  const qty = 1000;
  aircrafts[opts[0]] = durs.slice(0, qty).map(d => d.dur);
  aircrafts[opts[1]] = durs.slice(5000, 5000 + qty).map(d => d.dur);
  aircrafts[opts[2]] = durs.slice(10000, 10000 + qty).map(d => d.dur);
  console.log(aircrafts);
  render(aircrafts[xColumn]);
  });
